@@ -42,6 +42,9 @@ const (
 	EnvClientSecret = envNamespace + "CLIENT_SECRET"
 )
 
+// EnvAccessToken Authenticate using Access Token client.
+const EnvAccessToken = envNamespace + "ACCESS_TOKEN"
+
 // Record a DNS record.
 type Record struct {
 	ID        int64  `json:"id,omitempty"`
@@ -68,6 +71,8 @@ type Config struct {
 
 	OAuth2Config *OAuth2Config
 
+	AccessToken string
+
 	PropagationTimeout time.Duration
 	PollingInterval    time.Duration
 	TTL                int
@@ -111,6 +116,8 @@ func NewDNSProvider() (*DNSProvider, error) {
 	config.ApplicationSecret = env.GetOrFile(EnvApplicationSecret)
 	config.ConsumerKey = env.GetOrFile(EnvConsumerKey)
 
+	config.AccessToken = env.GetOrFile(EnvAccessToken)
+
 	clientID := env.GetOrFile(EnvClientID)
 	clientSecret := env.GetOrFile(EnvClientSecret)
 
@@ -130,8 +137,20 @@ func NewDNSProviderConfig(config *Config) (*DNSProvider, error) {
 		return nil, errors.New("ovh: the configuration of the DNS provider is nil")
 	}
 
+	if config.OAuth2Config != nil && config.hasAppKeyAuth() && config.AccessToken != "" {
+		return nil, errors.New("ovh: can't use multiple authentication systems (ApplicationKey, OAuth2, Access Token)")
+	}
+
+	if config.OAuth2Config != nil && config.AccessToken != "" {
+		return nil, errors.New("ovh: can't use multiple authentication systems (OAuth2, Access Token)")
+	}
+
 	if config.OAuth2Config != nil && config.hasAppKeyAuth() {
-		return nil, errors.New("ovh: can't use both authentication systems (ApplicationKey and OAuth2)")
+		return nil, errors.New("ovh: can't use multiple authentication systems (ApplicationKey, OAuth2)")
+	}
+
+	if config.hasAppKeyAuth() && config.AccessToken != "" {
+		return nil, errors.New("ovh: can't use multiple authentication systems (ApplicationKey, Access Token)")
 	}
 
 	client, err := newClient(config)
@@ -242,6 +261,8 @@ func newClient(config *Config) (*ovh.Client, error) {
 		client, err = ovh.NewClient(config.APIEndpoint, config.ApplicationKey, config.ApplicationSecret, config.ConsumerKey)
 	case config.OAuth2Config != nil:
 		client, err = ovh.NewOAuth2Client(config.APIEndpoint, config.OAuth2Config.ClientID, config.OAuth2Config.ClientSecret)
+	case config.AccessToken != "":
+		client, err = ovh.NewAccessTokenClient(config.APIEndpoint, config.AccessToken)
 	default:
 		client, err = ovh.NewDefaultClient()
 	}
